==> tdm_2.0.0.tar.gz: tdm/R/all.Theirsm.R <==
all.Theirsm<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--       \n")
     note_for_Theirsm_input()
     cat("-----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
     TheirSMMpar<-edit(TheirSMMpar)
     TheirSMMpar<-ycheck(TheirSMMpar)
     cat("\n")
     cat("--------------------------------------------------------\n")
     cat("    --Theophylline IR input data information--          \n")
     note_for_Thesm_conc_input()
     cat("--------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                                 
     TheirSMpar<-edit(TheirSMpar)                                               
     TheirSMpar<-mscheck(TheirSMpar)                                            
     cat("\n")
     Their.sm(length(TheirSMpar$ts),TheirSMpar$conc,TheirSMpar$ts,TheirSMMpar[7,2],TheirSMMpar[6,2],TheirSMMpar[3,2],TheirSMMpar[2,2],TheirSMMpar[5,2],TheirSMMpar[1,2],TheirSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------\n")
     cat("    --Theophylline IR output data information--                  \n")
     note_for_Theirsm_output()
     cat("-----------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output1<-coutput
     show(coutput) 
     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],TheirSMMpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")     
     Their.more()                                 
}

==> tdm_2.2.6.tar.gz: tdm/R/all.Theirsm.R <==
all.Theirsm<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--       \n")
     note_for_Theirsm_input()
     cat("-----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
     TheirSMMpar<-edit(TheirSMMpar)
##     TheirSMMpar<-ycheck(TheirSMMpar)
     cat("\n")
     cat("--------------------------------------------------------\n")
     cat("    --Theophylline IR input data information--          \n")
     note_for_Thesm_conc_input()
     cat("--------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                                 
     TheirSMpar<-edit(TheirSMpar)                                               
     TheirSMpar<-mscheck(TheirSMpar)                                            
     cat("\n")
     Their.sm(length(TheirSMpar$ts),TheirSMpar$conc,TheirSMpar$ts,TheirSMMpar[7,2],TheirSMMpar[6,2],TheirSMMpar[3,2],TheirSMMpar[2,2],TheirSMMpar[5,2],TheirSMMpar[1,2],TheirSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------\n")
     cat("    --Theophylline IR output data information--                  \n")
     note_for_Theirsm_output()
     cat("-----------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output1<-coutput
     show(coutput) 
     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],TheirSMMpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")     
     Their.more()                                 
}
